@@ -171,6 +171,18 @@ int Preferences::Config_Load()
         }
     }
     catch (...){}
+    try
+    {
+        if (Reg_User->OpenKey(__T("Software\\MediaArea\\MediaInfo"), false))
+        {
+            //Test if donation was given
+            if (Reg_User->ValueExists("Donated"))
+                Donated=Reg_User->ReadInteger("Donated");
+            if (Donated)
+                Donate_Display=false;
+        }
+    }
+    catch (...){}
     if (Config(__T("Donated"))==__T("1"))
     {
         Donated=true;
@@ -473,17 +485,27 @@ int Preferences::ExplorerShell()
     List=__T(
         ".264;H264File\r\n"
         ".3g2;mpeg4File\r\n"
+        ".3ga;mpeg4File\r\n"    
         ".3gp;mpeg4File\r\n"
+        ".3gpa;mpeg4File\r\n"
         ".3gpp;mpeg4File\r\n"
+        ".aa3;ATRACFile\r\n"
         ".aac;AACFile\r\n"
+        ".aacp;AACFile\r\n"
+        ".adts;AACFile\r\n"
         ".ac3;AC3File\r\n"
+        ".act;WAVFile\r\n"
         ".aiff;AIFFFile\r\n"
         ".amr;AMRFile\r\n"
         ".ape;APEFile\r\n"
         ".asf;ASFFile\r\n"
+        ".at3;ATRACFile\r\n"
+        ".au;AUFile\r\n"
         ".avi;AVIFile\r\n"
         ".bdmv;BDMVFile\r\n"
         ".bmp;BMPFile\r\n"
+        ".bms;BMPFile\r\n"
+        ".caf;CAFFile\r\n"
         ".clpi;CLPIFile\r\n"
         ".dde;DolbyEFile\r\n"
         ".divx;AVIFile\r\n"
@@ -494,6 +516,8 @@ int Preferences::ExplorerShell()
         ".dvr-ms;DVRMSFile\r\n"
         ".eac3;EAC3File\r\n"
         ".evo;EVOFile\r\n"
+        ".f4a;mpeg4File\r\n"  
+        ".f4b;mpeg4File\r\n" 
         ".f4v;mpeg4File\r\n"
         ".flc;FLICFile\r\n"
         ".fli;FLICFile\r\n"
@@ -501,7 +525,9 @@ int Preferences::ExplorerShell()
         ".flv;FlashVideoFile\r\n"
         ".gvi;AVIFile\r\n"
         ".gif;GIFFile\r\n"
+        ".gis;GIFFile\r\n"
         ".h264;H264File\r\n"
+        ".h3d;JPEGFile\r\n"
         ".hdmov;MOVFile\r\n"
         ".ifo;IfoFile\r\n"
         ".isma;ISMAFile\r\n"
@@ -510,6 +536,7 @@ int Preferences::ExplorerShell()
         ".jp2;JPEGFile\r\n"
         ".jpeg;JPEGFile\r\n"
         ".jpg;JPEGFile\r\n"
+        ".jps;JPEGFile\r\n"
         ".m1s;mpegFile\r\n"
         ".m1t;mpegFile\r\n"
         ".m1v;mpegFile\r\n"
@@ -542,6 +569,7 @@ int Preferences::ExplorerShell()
         ".mpgx;mpegFile\r\n"
         ".mpls;MPLSFile\r\n"
         ".mpm;mpegFile\r\n"
+        ".mpo;JPEGFile\r\n"
         ".mpv;mpegFile\r\n"
         ".mts;mpegFile\r\n"
         ".mxf;MXFFile\r\n"
@@ -549,29 +577,37 @@ int Preferences::ExplorerShell()
         ".ogg;OGGFile\r\n"
         ".ogm;OGMFile\r\n"
         ".ogv;OGVFile\r\n"
+        ".oma;ATRACFile\r\n"
         ".opus;OpusFile\r\n"
         ".png;PNGFile\r\n"
+        ".pns;PNGFile\r\n"
         ".qcp;QCPFile\r\n"
         ".qt;QTFile\r\n"
         ".ra;RMFile\r\n"
         ".rm;RMFile\r\n"
         ".rmvb;FlashVideoFile\r\n"
         ".smv;SMVFile\r\n"
+        ".spx;SpeexFile\r\n"
         ".stl;STLFile\r\n"
         ".swf;FlashFile\r\n"
         ".tak;TakVideoFile\r\n"
+        ".thd;THDFile\r\n"
 	".tif;TIFFFile\r\n"
 	".tiff;TIFFFile\r\n"
+        ".tmf;mpegFile\r\n"
         ".tp;TPFile\r\n"
         ".trp;TRPFile\r\n"
         ".ts;tsFile\r\n"
         ".tta;TTAFile\r\n"
+        ".ty;mpegFile\r\n"
         ".vob;mpegFile\r\n"
+        ".vqf;VQFFile\r\n"
         ".w64;W64File\r\n"
         ".wav;WAVFile\r\n"
         ".webM;WebMFile\r\n"
         ".wma;WMAFile\r\n"
         ".wmv;WMVFile\r\n"
+        ".wtv;WTVFile\r\n"
         ".wv;WCFile\r\n"
         ".wvc;WVCFile\r\n"
         ".y4m;Y4MFile\r\n"
@@ -1064,7 +1100,9 @@ int Preferences::ShellToolTip()
     List=__T(
         ".264;H264File\r\n"
         ".3g2;mpeg4File\r\n"
+	".3ga;mpeg4File\r\n"
         ".3gp;mpeg4File\r\n"
+	".3gpa;mpeg4File\r\n"
         ".3gpp;mpeg4File\r\n"
         ".aac;AACFile\r\n"
         ".ac3;AC3File\r\n"
